SELECT          Account_Item.id,
                `Client`.lastName, `Client`.firstName, `Client`.patrName,
                IF(`Client`.sex = 1, '', '') AS sex,
                `Client`.birthDate,
                CONCAT(ClientPolicy.`serial`, ' ', ClientPolicy.number) AS policySN,
                Insurer.OGRN,
                Insurer.shortName,
                CONCAT(insKLADR.`name`, ' ', insKLADR.`socr`) AS InsurerArea,
                CONCAT(ClientDocument.`serial`, '  ', ClientDocument.number) AS documentSN,
                ClientDocument.date AS documentDate,
                getClientRegAddress(Event.client_id) AS address,
                IF(work.title IS NOT NULL,
                    work.title, ClientWork.freeInput) AS `workName`,
                rbSocStatusType.name AS socStatusName,
                Event.setDate AS begDate,
                Event.execDate AS endDate,
                SUM(Account_Item.amount) AS amount,
                rbEventProfile.code AS eventProfileCode,
                IF(Account_Item.service_id IS NOT NULL,
                   ItemMedicalAidProfile.code,
                   IF(Account_Item.visit_id IS NOT NULL, VisitMedicalAidProfile.code, EventMedicalAidProfile.code)
                  ) AS medicalAidProfileCode,
                Diagnosis.MKB,
                IF(DiagnosticResult.regionalCode IS NULL, EventResult.regionalCode,
                    DiagnosticResult.regionalCode) AS resultCode,
                SUM(Account_Item.`sum`) AS `sum`,
                IF(CONCAT(ClientPolicy.`serial`, ' ', ClientPolicy.number) = '','1','') AS specialCase,
                IF(Account_Item.visit_id IS NOT NULL, VisitSpeciality.OKSOCode,
                    IF(Account_Item.action_id IS NOT NULL,
                        IF(`Action`.person_id IS NOT NULL, ActionSpeciality.OKSOCode,
                        ActionSetSpeciality.OKSOCode), EventSpeciality.OKSOCode)
                ) AS speciality,
                IF(Account_Item.service_id IS NOT NULL,
                    rbItemService.id,
                    IF(Account_Item.visit_id IS NOT NULL, rbVisitService.id, rbEventService.id)
                    ) AS serviceId
            FROM Account_Item
            LEFT JOIN Account ON Account_Item.master_id = Account.id
            LEFT JOIN `Action` ON Action.id = Account_Item.action_id
            LEFT JOIN Visit  ON Visit.id  = Account_Item.visit_id
            LEFT JOIN Event  ON Event.id  = Account_Item.event_id
            LEFT JOIN `Client` ON Client.id = Event.client_id
            LEFT JOIN ClientPolicy ON ClientPolicy.client_id = Client.id AND
                      ClientPolicy.id = (SELECT MAX(CP.id)
                                         FROM   ClientPolicy AS CP
                                         LEFT JOIN rbPolicyType AS CPT ON CPT.id = CP.policyType_id
                                         WHERE  CP.client_id = Client.id AND CP.deleted=0 AND CPT.code IN ('1','2'))
            LEFT JOIN Organisation AS Insurer ON Insurer.id = ClientPolicy.insurer_id
            LEFT JOIN kladr.KLADR  AS insKLADR ON insKLADR.code = Insurer.area
            LEFT JOIN ClientDocument ON ClientDocument.client_id = Client.id AND
                      ClientDocument.id = (SELECT MAX(CD.id)
                                         FROM   ClientDocument AS CD
                                         LEFT JOIN rbDocumentType AS rbDT ON rbDT.id = CD.documentType_id
                                         LEFT JOIN rbDocumentTypeGroup AS rbDTG ON rbDTG.id = rbDT.group_id
                                         WHERE  rbDTG.code = '1' AND CD.client_id = Client.id AND CD.deleted=0)
            LEFT JOIN Diagnostic ON ( Diagnostic.event_id = Account_Item.event_id
                                      AND Diagnostic.diagnosisType_id IN (SELECT id FROM rbDiagnosisType WHERE code IN ('1', '2'))
                                      AND Diagnostic.person_id = Event.execPerson_id AND Diagnostic.deleted = 0)
            LEFT JOIN ClientWork ON ClientWork.client_id=Event.client_id AND
                        ClientWork.id = (SELECT max(CW.id)
                                         FROM ClientWork AS CW
                                         WHERE CW.client_id=Client.id AND CW.deleted=0)
            LEFT JOIN Organisation AS work ON work.id=ClientWork.org_id AND work.deleted = 0
            LEFT JOIN Diagnosis ON Diagnosis.id = Diagnostic.diagnosis_id AND Diagnosis.deleted = 0
            LEFT JOIN rbResult AS DiagnosticResult ON DiagnosticResult.id=Diagnostic.result_id
            LEFT JOIN rbResult AS EventResult ON EventResult.id=Event.result_id
            LEFT JOIN EventType ON EventType.id = Event.eventType_id
            LEFT JOIN rbService AS rbEventService ON rbEventService.id = EventType.service_id
            LEFT JOIN rbService AS rbVisitService ON rbVisitService.id = Visit.service_id
            LEFT JOIN rbService AS rbItemService ON rbItemService.id = Account_Item.service_id
            LEFT JOIN rbPayRefuseType ON rbPayRefuseType.id = Account_Item.refuseType_id
            LEFT JOIN rbEventProfile ON EventType.eventProfile_id = rbEventProfile.id
            LEFT JOIN ClientSocStatus ON
                ClientSocStatus.client_id = `Client`.id AND
                ClientSocStatus.deleted = 0 AND
                ClientSocStatus.socStatusClass_id = (
                    SELECT rbSSC.id
                    FROM rbSocStatusClass AS rbSSC
                    WHERE rbSSC.code = '9' AND rbSSC.group_id IS NULL
                    LIMIT 0,1
                )
            LEFT JOIN rbSocStatusType ON
                ClientSocStatus.socStatusType_id = rbSocStatusType.id
            LEFT JOIN rbMedicalAidProfile AS EventMedicalAidProfile ON
                EventMedicalAidProfile.id = rbEventService.medicalAidProfile_id
            LEFT JOIN rbMedicalAidProfile AS VisitMedicalAidProfile ON
                VisitMedicalAidProfile.id = rbVisitService.medicalAidProfile_id
            LEFT JOIN rbMedicalAidProfile AS ItemMedicalAidProfile ON
                ItemMedicalAidProfile.id = rbItemService.medicalAidProfile_id
            LEFT JOIN Person AS VisitPerson ON Visit.person_id = VisitPerson.id
            LEFT JOIN Person AS ActionPerson ON `Action`.person_id = ActionPerson.id
            LEFT JOIN Person AS ActionSetPerson ON `Action`.setPerson_id = ActionSetPerson.id
            LEFT JOIN Person AS EventPerson ON Event.execPerson_id = EventPerson.id
            LEFT JOIN rbSpeciality AS VisitSpeciality ON VisitSpeciality.id = VisitPerson.speciality_id
            LEFT JOIN rbSpeciality AS ActionSpeciality ON ActionSpeciality.id = ActionPerson.speciality_id
            LEFT JOIN rbSpeciality AS ActionSetSpeciality ON ActionSetSpeciality.id = ActionSetPerson.speciality_id
            LEFT JOIN rbSpeciality AS EventSpeciality ON EventSpeciality.id = EventPerson.speciality_id
            WHERE
                Account_Item.reexposeItem_id IS NULL
            AND (Account_Item.date IS NULL
                 OR (Account_Item.date IS NOT NULL AND rbPayRefuseType.rerun != 0)
                )
            AND Account.id = :account_id
            GROUP BY `Account_Item`.`event_id`, serviceId